@@ -26,12 +26,20 @@ pub type OptHRef = Option<HRef>;
 #[derive(Debug, Clone)]
 pub struct HRef(String);
 
-impl<'href> From<&'href HRef> for &'href str {
-  fn from(value: &'href HRef) -> Self {
+impl<'a> From<&'a HRef> for &'a str {
+  /// Converts a reference to [HRef] into reference to str.
+  fn from(value: &'a HRef) -> Self {
     &value.0
   }
 }
 
+impl<'a> From<&'a HRef> for String {
+  /// Converts a reference to [HRef] into string.
+  fn from(value: &'a HRef) -> Self {
+    value.0.clone()
+  }
+}
+
 impl TryFrom<&str> for HRef {
   type Error = DmntkError;
   /// Tries to convert string into [HRef].
@@ -106,4 +114,18 @@ mod tests {
   fn invalid_references() {
     assert!(HRef::try_from("##").is_err());
   }
+
+  #[test]
+  fn href_into_str() {
+    let href = &HRef::try_from("#_c03e81bf-a53d-47c5-9135-189935765fdc").unwrap();
+    let actual: &str = href.into();
+    assert_eq!("_c03e81bf-a53d-47c5-9135-189935765fdc", actual);
+  }
+
+  #[test]
+  fn href_into_string() {
+    let href = &HRef::try_from("#_c03e81bf-a53d-47c5-9135-189935765fdc").unwrap();
+    let actual: String = href.into();
+    assert_eq!("_c03e81bf-a53d-47c5-9135-189935765fdc".to_string(), actual);
+  }
 }
